#
# spec file for package lollypop
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global gobject_introspection_version 1.35.9
Name:           lollypop
Version:        0.9.508
Release:        lp150.1.1
Summary:        GNOME music playing application
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
Url:            https://wiki.gnome.org/Apps/Lollypop
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  desktop-file-utils
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  meson >= 0.41
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= %{gobject_introspection_version}
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
# Can't migrate to GDBus, the server-side support is not implemented yet:
#     https://bugzilla.gnome.org/show_bug.cgi?id=656330
Requires:       dbus-1-python3
Requires:       gobject-introspection >= %{gobject_introspection_version}
Requires:       gstreamer-plugins-base
Requires:       python3-beautifulsoup4
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-pylast
Recommends:     %{name}-lang = %{version}
Recommends:     easytag
Recommends:     kid3-cli
Recommends:     lollypop-portal
Recommends:     python3-wikipedia
Recommends:     python3-pillow
BuildArch:      noarch

%description
Lollypop is a GNOME music playing application. It provides the following
features:
* Supports mp3/4, ogg and flac
* Genre/Cover browsing
* Genre/Artist/Cover browsing
* Search
* Main playlist (called queue in other apps)
* Party mode
* Replay gain
* Cover art downloader
* Context artist view
* MTP sync
* Fullscreen view
* Radios support
* Last.fm support
* Auto install codecs
* HiDPI support
* Tunein support.

%package -n gnome-shell-search-provider-lollypop
Summary:        GNOME music playing application - gnome-shell search provider
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    packageand(%{name}:gnome-shell)

%description -n gnome-shell-search-provider-lollypop
Lollypop is a GNOME music playing application.

This package contains a search provider to enable GNOME Shell to get
search results from %{name}.

%lang_package

%prep
%setup -q

%build
%meson

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files -f %{name}.lang
%doc AUTHORS README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%exclude %{_libexecdir}/lollypop-sp
%{_datadir}/%{name}
%{_datadir}/metainfo/org.gnome.Lollypop.appdata.xml
%{_datadir}/applications/org.gnome.Lollypop.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Lollypop.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Lollypop.png
%{_datadir}/icons/hicolor/*/apps/org.gnome.Lollypop-symbolic.svg
%{python3_sitelib}/lollypop/

%files -n gnome-shell-search-provider-%{name}
%{_libexecdir}/lollypop-sp
%{_datadir}/dbus-1/services/org.gnome.Lollypop.SearchProvider.service
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/lollypop-search-provider.ini

%changelog
* Thu May  3 2018 badshah400@gmail.com
- Update to version 0.9.508:
  * Do not empty ids. Fix glgo#gnumdk/lollypop#1414
  * Add <Alt>a shortcut to show current track artist. Fix
    glgo#gnumdk/lollypop#1413
  * Add Alt-a shortcut
  * Donation popup (beer, beer, beer)
  * Simpler radio widget
  * Handle external tracks as internal
  * Updated translations
- Add Recommends: python3-pillow: optional dependency.
* Sat Apr 28 2018 antoine.belvire@opensuse.org
- Update to version 0.9.507:
  * Fix crash. Fix #1405.
  * Spelling: Unplayed x2, USB.
  * Update translations.
  * Allow user to enable USB disk from UI. Fix #1403.
* Thu Apr 19 2018 antoine.belvire@opensuse.org
- Update to version 0.9.506:
  * Create information store on init. Fix #1402.
- Update to version 0.9.505:
  * Rework all Shuffle code.
  * Add some blur to lyrics view.
  * Import playlists from disk.
  * Allow exporting playlists to disk.
  * Bug fixes.
* Sat Apr 14 2018 antoine.belvire@opensuse.org
- Update to version 0.9.504:
  * Fix indicator in playlists.
  * Update translations
- Update to version 0.9.503:
  * Fix Enable network access ignored by lyrics and information
    popover.
- Update to version 0.9.502:
  * Fix a crash.
- Update to version 0.9.501:
  * Bug fixes.
- Update to 0.9.500:
  * Rework information popover.
  * New lyrics widget.
- Use %%license instead of %%doc for license file (boo#1082318).
- Add %%check section.
- Clean dependencies:
  * Add python3-beautifulsoup4 as runtime dependency (needed by
    new lyrics widget as well as existing artwork search
    feature).
  * Remove useless explicit dependencies:
    + gettext-runtime: Already required by intltool.
    + libxml2: Already required by itstool.
    + ninja: Already required by meson.
    + gstreamer: Already required by gstreamer-plugins-base.
    + pkgconfig(gio-2.0): Already required by pkgconfig(gtk+-3.0).
  * Remove fdupes (no duplicated files).
  * Remove unneeded hicolor-icon-theme.
  * Remove unneeded pkgconfig(gsettings-desktop-schemas).
  * Remove git-core (useless without internet access during
    build).
  * Add desktop-files-utils as build dependency (used in %%check
    section), remove it from runtime requirements.
* Wed Mar 28 2018 antoine.belvire@opensuse.org
- Update to version 0.9.403:
  * Workaround bgo#766284.
  * Show notifications when window is not visible.
  * Close notification on quit.
  * Fix a crash when trying to love a None track id.
- Update to version 0.9.402:
  * Quit app on SIGTERM/SIGINT.
  * Bugfixes.
- Update to version 0.9.401:
  * Fix an issue in Collection scanner.
  * Add an option to disable compilations.
* Fri Mar  9 2018 badshah400@gmail.com
- Update to version 0.9.400:
  * Fix meson build
  * Rework generate_data.sh
  * Updated translations
* Wed Dec 27 2017 antoine.belvire@opensuse.org
- Update to version 0.9.306:
  * Fix crash due to broken commit.
  * Add support for audio/x-wavpack.
  * Update GTK minimal version to 3.20.
  * Update translations.
- Changes from version 0.9.305:
  * Allow jumping to artist from search view.
  * Rework fullscreen layout.
  * Choose startup view.
- Update spec file:
  * Change URL and Source fields: Lollypop has moved to GNOME's
    infrastructure.
  * Drop post(un) scriptlets: They are empty for Tumbleweed and
    Leap 15 and this package does not build anymore with previous
    versions of openSUSE.
  * Drop glib2_gsettings_schema_requires (was needed for post(un)
    macros).
  * Drop conditionals for openSUSE Leap 42.3 and older.
  * Ran spec-cleaner.
- Add _service file.
* Mon Oct 16 2017 badshah400@gmail.com
- Update to version 0.9.303:
  + Make lollypop-cli working again
  + Do not remove tracks if collection does not exist
- Drop lollypop-libexecdir-location.patch, fixed upstream.
* Sun Oct  8 2017 jengelh@inai.de
- Trim description.
* Sat Oct  7 2017 kkirill@opensuse.org
- Update to version 0.9.303:
  + Another bug fix: sync code was broken
- Changes from version 0.9.302:
  + Fix important issue with flatpak package
  + Fix radios
* Wed Oct  4 2017 badshah400@gmail.com
- Update to version 0.9.300:
  + New "never played albums" section.
  + Remove all youtube-dl play code.
  + Bug fixes.
- Rebase lollypop-libexecdir-location.patch.
* Tue Jul 11 2017 badshah400@gmail.com
- Update to version 0.9.244:
  + Fix build issues which caused binary files to have
    non-executable permissions.
  + Drop rhythmbox2lollypop binary, and adapt its features into
    lollypop-cli.
- Update file list in keeping with rhythmbox2lollypop removal.
- No longer need to manually set exec perms on binaries, this is
  taken care of by the installer now.
- Update BuildRequires:
  + Explicitly require meson >= 0.40.0, as that is the least
    supported version now.
  + Explicitly require gettext-runtime >= 0.19.7 as building now
    requires `msgfmt --xml` which is only supported from this
    version (NB: gettext-runtime was being automatically pulled
    in earlier).
* Thu Jul  6 2017 badshah400@gmail.com
- Update to version 0.9.243:
  + Meson build
  + Fix a GTK require issue.
- Add lollypop-libexecdir-location.patch: Pick up libexecdir from
  option passed to meson instead of harcoding $prefix/libexecdir
  (we don't even use /usr/libexecdir).
* Mon Jul  3 2017 badshah400@gmail.com
- Update to version 0.9.241:
  + Fix an important issue with Spotify API
* Fri Jun 16 2017 badshah400@gmail.com
- Update to version 0.9.240:
  + Fix an issue with progressbar position on state restoration.
* Sat Jun  3 2017 badshah400@gmail.com
- Update to version 0.9.239:
  + Bug fixes, including for boo#1040253.
* Fri May 12 2017 badshah400@gmail.com
- Update to version 0.9.233:
  + Fix an important crash.
- Changes from version 0.9.232:
  + Bug fixes.
* Thu Apr 13 2017 badshah400@gmail.com
- Update to version 0.9.231:
  + Respect gtk dark theme setting.
  + Rework session management.
  + Enhanced mime type detection.
  + Allow lyrics for radios.
- Add Recommends on easytag: used when one clicks on the "edit
  tags" button in lollypop (boo#1033858).
- lollypop-sp moved to %%{_libexecdir}, adapt file-list
  appropriately.
* Fri Mar 24 2017 badshah400@gmail.com
- Update to version 0.9.230:
  + Bug fixes.
  + Enhanced charts support.
- Update file list for main package.
* Fri Feb  3 2017 badshah400@gmail.com
- Update to version 0.9.229:
  + Do not show charts in collection (Disable/Enable charts to
    fix it).
- Changes from version 0.9.228:
  + Fix an issue with MPRIS.
  + Do not list web artists in sync dialog.
  + Order tracks by name if no track number available.
- Add Recommends on lollypop-portal (now in factory) and
  kid3-cli (used to save tag changes to audio files).
* Tue Jan 17 2017 badshah400@gmail.com
- Update to version 0.9.227:
  + Fix an issue with Itunes charts.
  + Fix an issue with MPRIS.
  + Fix an issue with fast scrolling.
- Changes from version 0.9.226:
  + Do not use Gio for http downloads!
- Changes from version 0.9.225:
  + Bug fixes.
  + Show artists in sync view.
* Sat Jan  7 2017 badshah400@gmail.com
- Update to version 0.9.224:
  + Allow user to manually rate songs/albums.
  + Low quality image search fallback support when no Google API
    key available.
  + Playback fixes.
  + New fast scroll widget!
  + New loved album section.
  + Original date tag support.
  + FIX AN IMPORTANT MEMORY LEAK (on first collection scan).
  + Enhanced lyrics support.
  + Enhanced search widget.
  + Itunes search provider.
- Update file lists and %%suse_update_desktop_file usage to change
  in .desktop, icons and appdata file names.
* Thu Dec 15 2016 badshah400@gmail.com
- Update to version 0.9.223:
  + Bypass gvfs-http (bgo#775600).
  + Better search provider.
  + Now (opt) depends on lollypop-portal (not release yet, and so
    not in openSUSE so far):
    https://github.com/gnumdk/lollypop-portal.
- Changes from version 0.9.222:
  + Enhanced popularity behaviour.
  + Fix crash in playlist manager.
* Mon Nov 28 2016 badshah400@gmail.com
- Update to version 0.9.221:
  + Fix a crash with radio playback.
  + Small enhancements.
- Changes from version 0.9.220:
  + Fix crash in settings.
  + Fix crash in artwork dialog.
- Changes from version 0.9.219:
  + Fix an issue with some MTP devices.
  + Fix an issue with favorite tag editor.
  + Fix an issue with loved playlist.
* Wed Nov 23 2016 badshah400@gmail.com
- Update to version 0.9.218:
  + Fix an issue with search provider.
  + Simpler playback menu.
- Exclude from amain package and package the search provider
  utility -- %%{_datadir}/%%{name}/lollypop-sp -- as part of the
  gnome-shell-search-provider-lollypop, with exec attributes.
* Sun Nov 20 2016 badshah400@gmail.com
- Update to version 0.9.217:
  + Lollypop search provider.
  + Netease support for web playback.
  + Bug fixes.
- Split out a new package: gnome-shell-search-provider-lollypop
  to provide the search provider for gnome-shell.
- Add Group tags for all packages.
* Sun Nov 20 2016 badshah400@gmail.com
- Update to version 0.9.216:
  + Fix issue with radios.
- Changes from version 0.9.215:
  + New filtering feature.
  + Force GDK X11 backend (gh#gnumdk/lollypop#810).
  + Bugfixes.
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 0.9.214:
  + Allow using network share as collection.
  + Allow disabling charts.
  + Allow disabling network access.
* Sat Oct 15 2016 badshah400@gmail.com
- Update to version 0.9.211:
  + Fix an issue on Ubuntu 16.10.
  + Fix an issue with volume control.
- Changes from versions 0.9.207 through 0.9.210:
  + See release history at
    https://github.com/gnumdk/lollypop/releases.
- Bump up minimum required gtk3 version to 3.14 in keeping with
  config.ac file.
* Thu Sep 29 2016 badshah400@gmail.com
- Update to version 0.9.206:
  + Fix an issue with GTK 3.22.
  + Do not search in youtube based on audio length.
  + Add lollypop-cli command line helper.
* Fri Sep 23 2016 badshah400@gmail.com
- Update to version 0.9.205:
  + Youtube support.
  + MPRIS fixes.
  + Read lyrics from tags.
  + See https://github.com/gnumdk/lollypop/releases for full list
    of changes.
* Sun Sep  4 2016 mailaender@opensuse.org
- Update to version 0.9.113:
  + Enhanced search engine
  + MTP sync for albums
  + Move stats to settings dialog
  + Move artist artwork outside cache
  + Fix Lastfm scrobbler
  + Guess tracknumber from filename
  + Fix issues with Unity
  + Rework all code (may have introduced unwanted regressions)
* Fri Jul 15 2016 badshah400@gmail.com
- Update to version 0.9.112:
  + Fix an issue with image downloader:
    https://duckduckgo.com/i.js is not available anymore,
    duckduckgo API is limited to instant search... Switch to
    Google Custom Search (API key needed).
- Changes from versions 0.9.108 through 0.9.111:
  + See https://github.com/gnumdk/lollypop/releases.
* Sun Jun  5 2016 badshah400@gmail.com
- Update to version 0.9.107:
  + Bug fixes release.
- Changes from versions 0.9.106:
  + Option to store covers in tags (needs kid3).
  + Fix an issue in Fullscreen.
  + Other bug fixes.
- Changes from version 0.9.105:
  + Fix an issue with sortorder.
  + Fix an issue with HiDPI in MPRIS.
  + Fix issues with artwork cache.
  + Add support for shortcuts window.
* Sun May  8 2016 badshah400@gmail.com
- Update to version 0.9.104:
  + Fix an issue with read only fs
  + Add support for disc subtitle comment
  + Fix an issue with overlay
  + Remove arrow in list (bad with artist artwork, bad on
    elementary, ...)
- Changes from version 0.9.100 through 0.9.103:
  + See release history:
    https://github.com/gnumdk/lollypop/releases.
* Thu Apr 28 2016 badshah400@gmail.com
- Update to version 0.9.99:
  + Add support for artist artwork
  + Boost performance (one more time)
  + Bugfixes in collection scanner
  + Tunein search
- Add Recommends on python3-wikipedia for openSUSE > 1320,;
  enables the optional wikipedia feature (python3-wikipedia
  recently introduced into Factory). N.A. for openSUSE <= 13.2 or
  Leap 42.1.
* Wed Apr 27 2016 badshah400@gmail.com
- Update to version 0.9.98:
  + Last.fm was not working for users without Gnome Online
    Account.
  + Various bug fixes.
- Changes from version 0.9.97:
  + Fix an issue in MTP sync.
  + Fix an issue when showing artists for track.
- Changes from version 0.9.96:
  + Various bug fixes.
* Tue Apr 12 2016 badshah400@gmail.com
- Update to version 0.9.95:
  + Various bug fixes.
  + Enable Gnome Shell 3.20 MPRIS controls.
  + Move to GIO DBus on GNOME 3.20 (Thanks to Gnome Music code).
  + Should work again on Elementary OS.
- Delete unnecessary python cache files to avoid a ton of rpmlint
  warnings.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 0.9.94:
  + Fix an issue with HiDPI.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 0.9.93:
  + Fix an issue with overlays.
- Changes from version 0.9.92:
  + Allow multiple artists per album.
  + Faster album loading.
  + New Popover for context view.
  + Fixes for GNOME 3.20.
  + Remove Wikia support (broken) .
* Thu Mar 24 2016 badshah400@gmail.com
- Update to version 0.9.91:
  + Bug fixes.
- Changes from version 0.9.90:
  + Rewritten queue popover.
  + New playlists/albums popover (You can manage tracks/albums
    while browsing your collection).
  + New overlay buttons.
  + Drag & drop in playlists.
  + Fast queuing.
  + Multi playlists selection.
  + Jump to current track button.
  + Elementary OS support back.
* Wed Feb 17 2016 badshah400@gmail.com
- Update to version 0.9.86:
  + Fix an issue with crossfading.
  + Finally support artwork in notifications.
  + Add a new "responsive design" mode (Ctrl + m for Mini player).
  + Somes fixes in MTP sync.
- Changes from versions 0.9.83 through 0.9.85:
  + See upstream documentation of changes at
    https://github.com/gnumdk/lollypop/releases.
* Wed Feb  3 2016 badshah400@gmail.com
- Update to version 0.9.82:
  + Fix an important issue in collection scanner.
  + Fix an issue with progress bar.
- Changes from version 0.9.81:
  + Fix an issue in MTP code.
  + Update translations.
  + Rework settings dialog.
- Changes from version 0.9.80:
  + Crossfading support.
  + Allows user to merge views by selecting multiple items.
  + Converts files to MP3 on MTP sync (Android Phones, ...).
  + Fix an issue with headerbar.
* Thu Dec 24 2015 badshah400@gmail.com
- Update to version 0.9.75:
  + Use Duckduckgo, Google API is dead.
  +`Add a slider to select covers size.
* Sat Dec  5 2015 badshah400@gmail.com
- Update to version 0.9.74:
  + Fix issue in scanner.
- Changes from version 0.9.72:
  + Handle artist sort order tag.
  + Fix search dialog.
  + Allow popover in search dialog (Gtk 3.18).
- Changes from version 0.9.71:
  + Fix issue in fullscreen.
* Sat Nov 28 2015 badshah400@gmail.com
- Update to version 0.9.70:
  + Initial MPD support (unstable).
  + Animation when loading radios.
  + Stats in about dialog.
  + Restore window position when hidden.
  + Right click on albums.
  + Fix MTP errors.
* Fri Nov 13 2015 badshah400@gmail.com
- Initial package.
